@@ -1,29 +1,17 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "compositor.h"
 #include "event_queue.h"
 #include "region.h"
 #include "surface.h"
 #include "wayland_pointer_p.h"
 // Qt
+#include <QGuiApplication>
 #include <QRegion>
+#include <qpa/qplatformnativeinterface.h>
 
 #include <wayland-client-protocol.h>
 
@@ -32,7 +20,7 @@ namespace KWayland
 namespace Client
 {
 
-class Compositor::Private
+class Q_DECL_HIDDEN Compositor::Private
 {
 public:
     Private() = default;
@@ -52,6 +40,21 @@ Compositor::~Compositor()
     release();
 }
 
+Compositor *Compositor::fromApplication(QObject *parent)
+{
+    QPlatformNativeInterface *native = qApp->platformNativeInterface();
+    if (!native) {
+        return nullptr;
+    }
+    wl_compositor *compositor = reinterpret_cast<wl_compositor*>(native->nativeResourceForIntegration(QByteArrayLiteral("compositor")));
+    if (!compositor) {
+        return nullptr;
+    }
+    Compositor *c = new Compositor(parent);
+    c->d->compositor.setup(compositor, true);
+    return c;
+}
+
 void Compositor::setup(wl_compositor *compositor)
 {
     Q_ASSERT(compositor);
